<?php
/*
Plugin Name: Meta Keywords Plugin
Plugin URI: https://www.zinavo.com/meta-keywords-optimize-wordpress-plugin.html
Description: A plugin to add meta keywords dynamically to all pages.
Version: 1.1
Author: Zinavo
Author URI: https://www.zinavo.com/
*/

// Modify plugin row meta links
function mkp_plugin_meta_links($links, $file) {
    if ($file === plugin_basename(__FILE__)) {
        // Modify the "Visit plugin site" link to "View details"
        foreach ($links as &$link) {
            if (strpos($link, 'href="https://www.zinavo.com/meta-keywords-optimize-wordpress-plugin.html"') !== false) {
                $link = '<a href="https://www.zinavo.com/meta-keywords-optimize-wordpress-plugin.html" target="_blank">View details</a>';
            }
        }

        // Add Documentation link
        $links[] = '<a href="https://www.zinavo.com/wp-content/uploads/2025/02/Documentation-for-Meta-Keywords-Optimize-WordPress-Plugin.pdf" target="_blank">Documentation</a>';
        
        // Add Video Tutorials link
        $links[] = '<a href="https://youtu.be/dvJFK2rK8JM" target="_blank">Video Tutorials</a>';
    }
    return $links;
}
add_filter('plugin_row_meta', 'mkp_plugin_meta_links', 10, 2);


// Add a meta box for keyword input on all post/page edit screens
function mkp_add_meta_box() {
    add_meta_box(
        'mkp_meta_keywords', // ID of the meta box
        'Meta Keywords', // Title of the meta box
        'mkp_meta_box_callback', // Callback function
        ['post', 'page'], // Screens (post & page)
        'side', // Context (sidebar)
        'default' // Priority
    );
}
add_action('add_meta_boxes', 'mkp_add_meta_box');

// HTML content for the meta box
function mkp_meta_box_callback($post) {
    wp_nonce_field('mkp_save_meta_keywords', 'mkp_meta_keywords_nonce');
    $meta_keywords = get_post_meta($post->ID, '_mkp_meta_keywords', true);
    ?>
    <label for="mkp_meta_keywords">Enter meta keywords</label>
    <input type="text" name="mkp_meta_keywords" id="mkp_meta_keywords" value="<?php echo esc_attr($meta_keywords); ?>" style="width:100%;margin-top:10px;" />
    <?php
}

// Save the meta keywords when the post is saved
function mkp_save_meta_keywords($post_id) {
    // Security Checks
    if (!isset($_POST['mkp_meta_keywords_nonce']) || !wp_verify_nonce($_POST['mkp_meta_keywords_nonce'], 'mkp_save_meta_keywords')) {
        return;
    }
    if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) {
        return;
    }
    if (!current_user_can('edit_post', $post_id)) {
        return;
    }

    // Save meta keywords
    if (isset($_POST['mkp_meta_keywords'])) {
        update_post_meta($post_id, '_mkp_meta_keywords', sanitize_text_field($_POST['mkp_meta_keywords']));
    }
}
add_action('save_post', 'mkp_save_meta_keywords');

// Add the meta keywords to the <head> section of the page
function mkp_add_meta_keywords_to_head() {
    if (is_singular() || is_front_page() || is_home()) {
        global $post;
        if ($post) {
            $meta_keywords = get_post_meta($post->ID, '_mkp_meta_keywords', true);
            if (!empty($meta_keywords)) {
                echo '<meta name="keywords" content="' . esc_attr($meta_keywords) . '" />' . "\n";
            }
        }
    }

    // Debugging log to check if function runs
    error_log('Meta Keywords Plugin Executed');
}
add_action('wp_head', 'mkp_add_meta_keywords_to_head');
